@@ -12,7 +12,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::Prepender;
 # ABSTRACT: prepend lines at the top of your perl files
-$Dist::Zilla::Plugin::Prepender::VERSION = '2.000';
+$Dist::Zilla::Plugin::Prepender::VERSION = '2.001';
 use Moose;
 use MooseX::Has::Sugar;
 
@@ -38,6 +38,7 @@ has _skips => (
     default    => sub { [] },
 );
 
+our $DZIL_5 = eval { Dist::Zilla->VERSION(5.000) };
 
 # -- public methods
 
@@ -53,7 +54,7 @@ sub munge_file {
         $self->log_debug($file->name . ' is not a mutable type, skipping...');
         return;
     }
-
+    return if $DZIL_5 and $file->encoding eq 'bytes';
     return $self->_munge_perl($file) if $file->name    =~ /\.(?:pm|pl)$/i;
     return $self->_munge_perl($file) if $file->content =~ /^#!(?:.*)perl(?:$|\s)/;
     return;
@@ -123,7 +124,7 @@ Dist::Zilla::Plugin::Prepender - prepend lines at the top of your perl files
 
 =head1 VERSION
 
-version 2.000
+version 2.001
 
 =head1 SYNOPSIS
 
